
.btn {
  display: inline-block;
  width: auto;
}
.btn + .btn {
  margin-top: 0;
  margin-left: 0.75rem;
}
.post {
  background: #fff;
  box-shadow: 0 2px 5px rgba(0,0,0,0.1);
  margin-bottom: 2em;
  padding: 1em;
  border-radius: 4px;
}
.post-date {
  color: #777;
  font-size: 0.85em;
  margin-bottom: 1em;
  display: block;
}

.post-highlight {
  max-width: 20em; /* Assuming the base font-size is 16px, 12.5em is equivalent to 200px */
  margin-right: 1em;
  margin-left: 1em;
}

@media (max-width: 768px) {
  .post-highlight {
    max-width: 30em; /* Larger size on mobile */
  }
}

.post-content {
  display: flex;
  align-items: flex-start;
  flex: 1;
}

.chat-transcript {
    font-family: 'Courier New', Courier, monospace;
    background-color: #000;
    color: #0f0;
    padding: 1em 1em 1em 1em;
    border-radius: 5px;
    margin-top: 50px;
}

.chat-transcript blockquote {
    padding: 0;
    margin-left: 0;
    color: #819198;
    border-left: none
}

.chat-transcript blockquote>:first-child {
    margin-top: 0
}

.chat-transcript blockquote>:last-child {
    margin-bottom: 0
}


.chat-transcript li,
.chat-transcript p {
    color: #00FFFF;
}

.chat-transcript h1 {
    display: none;
}

.chat-transcript h4 {
    color: #32FF32;
    border-top: 1px solid #32FF32;
    padding-top: 10px;
    text-transform: none;
    font-size: 1.0rem !important;
}

.chat-transcript h4::before {
    content: '> ';
}

.chat-transcript blockquote p {
    color: #ffffff;
}
.chat-transcript::before {
    content: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" width="90" height="25"><circle cx="7" cy="15" r="7" fill="%23f92672"/><circle cx="27" cy="15" r="7" fill="%23f4bf75"/><circle cx="47" cy="15" r="7" fill="%23a6e22e"/></svg>');
    display: block;
    margin-bottom: 0;
    position: relative;
    top: -0.5em;
}


.chat-transcript,
div.highlighter-rouge pre.highlight, div.highlighter-rouge code {
    line-height: 1.1;
}

@import "../global-overrides.scss";

.site-header {
    background-color: #1a1a1a;
    border-bottom: 1px solid #333;
    grid-area: topnav; // Assign to top navigation area
}

.site-title, .site-title:visited {
    color: #f8f9fa;
}

.nav-list .nav-list-item .nav-list-link {
    color: #adb5bd;
}

.nav-list .nav-list-item .nav-list-link:hover, .nav-list .nav-list-item .nav-list-link.active {
    color: #4c6ef5;
}

.main-content {
    background-color: #121212;
    grid-area: main; // Assign to main content area
}

.main-content h1, .main-content h2, .main-content h3, .main-content h4, .main-content h5, .main-content h6 {
    color: #f8f9fa;
}

.main-content p, .main-content li, .main-content td, .main-content th {
    color: #adb5bd;
}

.main-content a {
    color: #ffffff;
    text-decoration: underline;
}

.main-content a:hover {
    color: #f8f9fa;
    text-decoration: none;
}

.main-content code {
    background-color: #1e1e1e;
    color: #f8f9fa;
}

.main-content pre {
    background-color: #1e1e1e;
    border-color: #333;
}

.main-content table {
    background-color: #1a1a1a;
}

.main-content table th {
    background-color: #2a2a2a;
    border-color: #333;
}

.main-content table td {
    border-color: #333;
}

.search-input {
    background-color: #1a1a1a;
    border-color: #333;
    color: #f8f9fa;
}

.search-input:focus {
    background-color: #2a2a2a;
}

.search-result-doc {
    background-color: #1a1a1a;
}

.search-result-doc:hover {
    background-color: #2a2a2a;
}

.btn {
    background-color: #2a2a2a;
    color: #f8f9fa;
    border-color: #333;
}

.btn:hover {
    background-color: #3a3a3a;
}

// Auxiliary navigation (top nav) styles for dark mode
.aux-nav {
    background-color: #1a1a1a;
}

.aux-nav-list-item {
    background-color: #2a2a2a;
}

.site-button {
    background-color: #2a2a2a;
    color: #f8f9fa;
    border-color: #333;
}

.site-button:hover {
    background-color: #3a3a3a;
}

// Sidebar gradient fix for dark mode
.side-bar {
    background-color:#121212 !important;
    grid-area: sidebar; // Assign to sidebar area
    position: static !important; // Remove fixed positioning for grid
    height: 100vh; // Full height
    overflow-y: auto; // Scroll if content is too tall
}

// Hide blog link in documentation
.aux-nav-list-item a[href="/blog/"] {
    display: none !important;
}

// Grid layout adjustments for larger screens
@media (min-width: 1200px) {
    body {
        grid-template-columns: 300px 1fr;
    }
    
    .side-bar {
        width: 300px !important;
    }
    
    .main-content-wrap {
        padding-left: 48px !important;
        padding-right: 48px !important;
        max-width: 100% !important;
    }
}

// For very large screens (1920px and above)
@media (min-width: 1920px) {
    body {
        grid-template-columns: 320px 1fr;
    }
    
    .side-bar {
        width: 320px !important;
    }
    
    .main-content-wrap {
        padding-left: 64px !important;
        padding-right: 64px !important;
        max-width: 1600px !important;
        margin-left: auto !important;
        margin-right: auto !important;
    }
}

.site-footer {
    background-color: #0a0a0a;
    color: #adb5bd;
}

.site-footer a {
    color: #4c6ef5;
}

// Callout styles for dark mode
.callout {
    background-color: #1a1a1a;
    border-color: #333;
}

.callout-tip {
    background-color: rgba(18, 184, 134, 0.1);
}

.callout-note {
    background-color: rgba(241, 196, 15, 0.1);
}

// Syntax highlighting for dark mode
.highlight {
    background-color: #1e1e1e;
}

.highlight .c, .highlight .c1 { color: #6a9955; } /* Comment */
.highlight .k, .highlight .kd { color: #569cd6; } /* Keyword */
.highlight .s, .highlight .s1 { color: #ce9178; } /* String */
.highlight .na { color: #9cdcfe; } /* Name.Attribute */
.highlight .nb { color: #dcdcaa; } /* Name.Builtin */
.highlight .nc { color: #4ec9b0; } /* Name.Class */
.highlight .no { color: #b5cea8; } /* Name.Constant */
.highlight .nd { color: #c586c0; } /* Name.Decorator */
.highlight .ni { color: #d4d4d4; } /* Name.Entity */
.highlight .ne { color: #d16969; } /* Name.Exception */
.highlight .nf { color: #dcdcaa; } /* Name.Function */
.highlight .nl { color: #dcdcaa; } /* Name.Label */
.highlight .nn { color: #4ec9b0; } /* Name.Namespace */
.highlight .nt { color: #569cd6; } /* Name.Tag */
.highlight .nv { color: #9cdcfe; } /* Name.Variable */
.highlight .ow { color: #569cd6; } /* Operator.Word */
.highlight .w { color: #d4d4d4; } /* Text.Whitespace */
.highlight .mb { color: #b5cea8; } /* Literal.Number.Bin */
.highlight .mf { color: #b5cea8; } /* Literal.Number.Float */
.highlight .mh { color: #b5cea8; } /* Literal.Number.Hex */
.highlight .mi { color: #b5cea8; } /* Literal.Number.Integer */
.highlight .mo { color: #b5cea8; } /* Literal.Number.Oct */
.highlight .sa { color: #ce9178; } /* Literal.String.Affix */
.highlight .sb { color: #ce9178; } /* Literal.String.Backtick */
.highlight .sc { color: #ce9178; } /* Literal.String.Char */
.highlight .dl { color: #ce9178; } /* Literal.String.Delimiter */
.highlight .sd { color: #6a9955; } /* Literal.String.Doc */
.highlight .s2 { color: #ce9178; } /* Literal.String.Double */
.highlight .se { color: #d16969; } /* Literal.String.Escape */
.highlight .sh { color: #ce9178; } /* Literal.String.Heredoc */
.highlight .si { color: #ce9178; } /* Literal.String.Interpol */
.highlight .sx { color: #ce9178; } /* Literal.String.Other */
.highlight .sr { color: #d16969; } /* Literal.String.Regex */
.highlight .s1 { color: #ce9178; } /* Literal.String.Single */
.highlight .ss { color: #ce9178; } /* Literal.String.Symbol */
.highlight .bp { color: #dcdcaa; } /* Name.Builtin.Pseudo */
.highlight .fm { color: #dcdcaa; } /* Name.Function.Magic */
.highlight .vc { color: #9cdcfe; } /* Name.Variable.Class */
.highlight .vg { color: #9cdcfe; } /* Name.Variable.Global */
.highlight .vi { color: #9cdcfe; } /* Name.Variable.Instance */
.highlight .vm { color: #9cdcfe; } /* Name.Variable.Magic */
.highlight .il { color: #b5cea8; } /* Literal.Number.Integer.Long */
