// Footer styles for cecli website

footer {
    background-color: #0a0a0a; // Darker footer background
    color: white;
    padding: 40px 0;
    text-align: center;
}

.footer-links {
    margin-bottom: 20px;
}

.footer-links a {
    color: white;
    text-decoration: none;
    margin: 0 10px;
    transition: color 0.3s;
}

.footer-links a:hover {
    color: var(--primary);
}

.copyright {
    color: var(--gray);
    font-size: 0.9rem;
}